==> okteta-0.25.3.tar.xz: okteta-0.25.3/kasten/controllers/view/structures/datatypes/strings/stringdata.cpp <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2011 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#include "stringdata.h"
#include "stringdatainformation.h"

StringData::StringData(StringDataInformation* parent)
    : mParent(parent)
    , mMode(None)
    , mLittleEndian(true)
    , mEofReached(false)
{
    // default to zero terminated strings
    mLength.maxBytes = 0;
}

StringData::~StringData() = default;

void StringData::setTerminationCodePoint(uint term)
{
    if (term > UNICODE_MAX) {
        mParent->logError() << "Attempting to set termination code point which is larger"
            " than 0x10ffff (max unicode):" << term;
        return;
    }
    mTerminationCodePoint = term;
    mMode |= Sequence;
}

void StringData::setLittleEndian(bool littleEndian)
{
    mLittleEndian = littleEndian;
}

==> okteta-0.26.3.tar.xz: okteta-0.26.3/kasten/controllers/view/structures/datatypes/strings/stringdata.cpp <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2011 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#include "stringdata.hpp"
#include "stringdatainformation.hpp"

StringData::StringData(StringDataInformation* parent)
    : mParent(parent)
    , mMode(None)
    , mLittleEndian(true)
    , mEofReached(false)
{
    // default to zero terminated strings
    mLength.maxBytes = 0;
}

StringData::~StringData() = default;

void StringData::setTerminationCodePoint(uint term)
{
    if (term > UNICODE_MAX) {
        mParent->logError() << "Attempting to set termination code point which is larger"
            " than 0x10ffff (max unicode):" << term;
        return;
    }
    mTerminationCodePoint = term;
    mMode |= Sequence;
}

void StringData::setLittleEndian(bool littleEndian)
{
    mLittleEndian = littleEndian;
}
